@@ -4,7 +4,13 @@ use strict;
 use warnings;
 use Carp qw/croak confess/;
 
-our $VERSION = "0.084";
+our $VERSION = "0.085";
+
+use constant {
+    DEFAULT_COMMAND_TIMEOUT => 1.0,
+    DEFAULT_CONNECT_TIMEOUT => 1.0,
+    DEFAULT_MAX_RETRY_COUNT => 5,
+};
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -21,19 +27,19 @@ sub new {
     }
 
     my $connect_timeout = $args{connect_timeout};
-    $connect_timeout = 10 unless $connect_timeout;
+    $connect_timeout = DEFAULT_CONNECT_TIMEOUT unless defined $connect_timeout;
     $self->__set_connect_timeout($connect_timeout);
 
     my $command_timeout = $args{command_timeout};
-    $command_timeout = 10 unless $command_timeout;
+    $command_timeout = DEFAULT_COMMAND_TIMEOUT unless defined $command_timeout;
     $self->__set_command_timeout($command_timeout);
 
     my $max_retry = $args{max_retry_count};
-    $max_retry = 10 unless $max_retry;
+    $max_retry = DEFAULT_MAX_RETRY_COUNT unless defined $max_retry;
     $self->__set_max_retry($max_retry);
 
-    croak "failed to connect redis servers"
-        if $self->connect();
+    my $error = $self->__connect();
+    croak $error if $error;
     return $self;
 }
 
@@ -43,7 +49,7 @@ our $AUTOLOAD;
 sub AUTOLOAD {
     my $command = $AUTOLOAD;
     $command =~ s/.*://;
-    my @command = split /_/, uc $command;
+    my @command = split /_/, $command;
 
     my $method = sub {
         my $self = shift;
@@ -97,7 +103,7 @@ Redis::Cluster::Fast - A fast perl binding for Redis Cluster
         ],
         connect_timeout => 0.05,
         command_timeout => 0.05,
-        max_retry => 10,
+        max_retry_count => 10,
     );
 
     $redis->set('test', 123);
@@ -128,39 +134,68 @@ Require Redis 6 or higher to support L<RESP3|https://github.com/antirez/RESP3/bl
 
 To build this module you need at least autoconf, automake, libtool, patch, pkg-config are installed on your system.
 
+=head2 MICROBENCHMARK
+
+Simple microbenchmark comparing PP and XS.
+The benchmark script used can be found under examples directory.
+
+    Redis::Cluster::Fast is 0.084
+    Redis::ClusterRider is 0.26
+    ### mset ###
+                            Rate  Redis::ClusterRider Redis::Cluster::Fast
+    Redis::ClusterRider  13245/s                   --                 -34%
+    Redis::Cluster::Fast 20080/s                  52%                   --
+    ### mget ###
+                            Rate  Redis::ClusterRider Redis::Cluster::Fast
+    Redis::ClusterRider  14641/s                   --                 -40%
+    Redis::Cluster::Fast 24510/s                  67%                   --
+    ### incr ###
+                            Rate  Redis::ClusterRider Redis::Cluster::Fast
+    Redis::ClusterRider  18367/s                   --                 -44%
+    Redis::Cluster::Fast 32879/s                  79%                   --
+    ### new and ping ###
+                           Rate  Redis::ClusterRider Redis::Cluster::Fast
+    Redis::ClusterRider   146/s                   --                 -96%
+    Redis::Cluster::Fast 3941/s                2598%                   --
+
 =head1 METHODS
 
 =head2 new(%args)
 
 Following arguments are available.
 
-=over 4
-
-=item startup_nodes
+=head3 startup_nodes
 
 Specifies the list of Redis Cluster nodes.
 
-=item connect_timeout
+=head3 connect_timeout
 
-A fractional seconds. (default: 10)
+A fractional seconds. (default: 1.0)
 
 Connection timeout to connect to a Redis node.
 
-=item command_timeout
+=head3 command_timeout
 
-A fractional seconds. (default: 10)
+A fractional seconds. (default: 1.0)
 
-Redis Command execution timeout.
+Specifies the timeout value for each read/write event to execute a Redis Command.
 
-=item max_retry
+=head3 max_retry_count
 
-A integer value. (default: 10)
+A integer value. (default: 5)
 
-=back
+The client will retry calling the Redis Command only if it successfully get one of the following error responses.
+MOVED, ASK, TRYAGAIN, CLUSTERDOWN.
+
+C<mas_retry_count> is the maximum number of retries and must be 1 or above.
 
 =head2 <command>(@args)
 
-To run Redis command with arguments.
+To run a Redis command with arguments.
+
+The command can also be expressed by concatenating the subcommands with underscores.
+
+    e.g. cluster_info
 
 =head1 LICENSE
 
